@@ -75,7 +75,7 @@ MODULE_LICENSE("Dual BSD/GPL");
 MODULE_SUPPORTED_DEVICE("sis1100/sis3100/sis5100; http://www.struck.de/pcivme.htm");
 
 #define DRIVER_VERSION "2.13"
-#define DATE_STRING "2010-01-22"
+#define DATE_STRING "2012-01-19"
 #define NAME_STRING "Forschungszentrum Juelich"
 
 struct sis1100_softc *sis1100_devdata[sis1100_MAXCARDS];
@@ -149,11 +149,19 @@ show_remote_size SHOW_ARGS(struct device* d, struct device_attribute *attr, char
     return snprintf(buf, PAGE_SIZE, "0x%llx\n",
         (unsigned long long)pci_resource_len(sc->pdev, 3));
 }
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,34)
+ssize_t
+show_version(struct class* c, struct class_attribute *attr, char *buf)
+{
+    return snprintf(buf, PAGE_SIZE, DRIVER_VERSION "\n");
+}
+#else
 ssize_t
 show_version(struct class* c, char *buf)
 {
     return snprintf(buf, PAGE_SIZE, DRIVER_VERSION "\n");
 }
+#endif
 
 static DEVICE_ATTR(driver_version, 0444, show_driver_version, 0);
 static DEVICE_ATTR(local_ident, 0444, show_local_ident, 0);
